@@ -5,13 +5,15 @@ set -e
 # The testsuite has a sad if you're in a non-UTF-8 locale:
 export LANG='C.UTF-8'
 
-dpkg-checkbuilddeps -d 'python3-apt, apt-btrfs-snapshot, parsewiki, python-feedparser,
-			python3-mock, xvfb, gir1.2-gtk-3.0, python3-gi, python3-nose, pep8, python3-distutils-extra'
+dpkg-checkbuilddeps -d 'python3-apt, apt-btrfs-snapshot, parsewiki, python3-feedparser,
+			python3-mock, xvfb, gir1.2-gtk-3.0, python3-gi, python3-nose, pep8, python3-distutils-extra, python3-update-manager'
 
 # update demotions
-(cd utils && ./demotions.py vivid wily > demoted.cfg)
+# echo "Running demotions"
+# (cd utils && ./demotions.py wily xenial > demoted.cfg)
 # when this gets enabled, make sure to add symlink in DistUpgrade
-#(cd utils && ./demotions.py trusty w00t > demoted.cfg.trusty)
+# echo "Running lts demotions"
+(cd utils && ./demotions.py trusty xenial > demoted.cfg.trusty)
 
 # update apt_btrfs_snapshot.py copy, this needs an installed
 # apt-btrfs-snapshot on the build machine
@@ -34,13 +36,15 @@ fi
 
 # cleanup
 rm -rf utils/apt/lists utils/apt/*.bin
+# echo "Running update mirrors"
 (cd utils && ./update_mirrors.py ../data/mirrors.cfg)
 
 # run the test-suite
-#echo "Running integrated tests"
-nosetests3
+# echo "Running integrated tests"
+xvfb-run nosetests3
 
 # test leftovers
+# echo "Cleaning up after tests"
 rm -f ./tests/data-sources-list-test/apt.log
 
 # update version
