@@ -24,6 +24,15 @@ class MockConfig(object):
     pass
 
 
+def make_mock_pkg(name, is_installed, candidate_rec):
+    mock_pkg = mock.Mock()
+    mock_pkg.name = name
+    mock_pkg.is_installed = is_installed
+    mock_pkg.candidate = mock.Mock()
+    mock_pkg.candidate.record = candidate_rec
+    return mock_pkg
+
+
 class TestPatches(unittest.TestCase):
 
     orig_chdir = ''
@@ -85,7 +94,7 @@ class TestPatches(unittest.TestCase):
         self._verify_result_checksums()
 
     def test_patch_lowlevel(self):
-        #test lowlevel too
+        # test lowlevel too
         from DistUpgrade.DistUpgradePatcher import patch, PatchError
         self.assertRaises(PatchError, patch, CURDIR + "/patchdir/fail",
                           CURDIR + "/patchdir/patchdir_fail."
@@ -145,7 +154,7 @@ class TestQuirks(unittest.TestCase):
                            ["pci:v00001002d00006702sv*sd*bc03sc*i*",
                             "pci:v00001001d00006702sv*sd*bc03sc*i*"])])
 
-    def testFglrx(self):
+    def disabled__as_fglrx_is_gone_testFglrx(self):
         mock_lspci_good = set(['1002:9990'])
         mock_lspci_bad = set(['8086:ac56'])
         config = mock.Mock()
@@ -186,6 +195,55 @@ class TestQuirks(unittest.TestCase):
         res = quirks._stopPokeScreensaver()
         res  # pyflakes
 
+    def test_get_linux_metapackage(self):
+        q = DistUpgradeQuirks(mock.Mock(), mock.Mock())
+        mock_cache = set([
+            make_mock_pkg(
+                name="linux-image-3.19-24-generic",
+                is_installed=True,
+                candidate_rec={"Source": "linux"},
+            ),
+        ])
+        pkgname = q._get_linux_metapackage(mock_cache, headers=False)
+        self.assertEqual(pkgname, "linux-generic")
+
+    def test_get_lpae_linux_metapackage(self):
+        q = DistUpgradeQuirks(mock.Mock(), mock.Mock())
+        mock_cache = set([
+            make_mock_pkg(
+                name="linux-image-4.2.0-16-generic-lpae",
+                is_installed=True,
+                candidate_rec={"Source": "linux"},
+            ),
+        ])
+        pkgname = q._get_linux_metapackage(mock_cache, headers=False)
+        self.assertEqual(pkgname, "linux-generic-lpae")
+
+    def test_get_lowlatency_linux_metapackage(self):
+        q = DistUpgradeQuirks(mock.Mock(), mock.Mock())
+        mock_cache = set([
+            make_mock_pkg(
+                name="linux-image-4.2.0-16-lowlatency",
+                is_installed=True,
+                candidate_rec={"Source": "linux"},
+            ),
+        ])
+        pkgname = q._get_linux_metapackage(mock_cache, headers=False)
+        self.assertEqual(pkgname, "linux-lowlatency")
+
+    def test_get_lts_linux_metapackage(self):
+        q = DistUpgradeQuirks(mock.Mock(), mock.Mock())
+        mock_cache = set([
+            make_mock_pkg(
+                name="linux-image-3.13.0-24-generic",
+                is_installed=True,
+                candidate_rec={"Source": "linux-lts-quantal"},
+            ),
+        ])
+        pkgname = q._get_linux_metapackage(mock_cache, headers=False)
+        self.assertEqual(pkgname, "linux-generic-lts-quantal")
+
+
 if __name__ == "__main__":
     import logging
     logging.basicConfig(level=logging.DEBUG)
